gc3libs.application.apppot — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.application.apppot

Support for AppPot-hosted applications.

For more details about AppPot, visit: <http://apppot.googlecode.com>

class `gc3libs.application.apppot.` `AppPotApplication`(arguments, inputs, outputs, output_dir, apppot_img=None, apppot_changes=None, apppot_tag='ENV/APPPOT-0.21', apppot_extra=[], **extra_args)

  Base class for AppPot-hosted applications. Provides the same interface as the base `Application` and runs the specified command in an AppPot instance.

  In addition to the standard `Application` keyword arguments, the following ones can be given to steer the AppPot execution:

  - apppot_img: Path or URL to the AppPot system image to use. If `None` (default), then the default AppPot system image on the remote system is used.
  - apppot_changes: Path or URL to an AppPot changes file to be merged at system startup.
  - apppot_tag: ARC RTE to use for submission of this AppPot job.
  - apppot_extra: List of additional UML boot command-line arguments. (Passed to the AppPot instance via `apppot-start`‘s `--extra` option.)

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »